@@ -33,7 +33,7 @@ def new_cert(ca_private_key_pem, csr_pem, validity_td, issuer_name, bits=2048,
     cert = M2Crypto.X509.X509()
 
     sn = sapi.config.ca.SERIAL_NUMBER_GENERATOR_CB()
-    if issubclass(sn.__class__, sapi.normal.basestring) is True:
+    if issubclass(sn.__class__, sapi.normal.basestring_) is True:
         sn = int(sn, 16)
 
     cert.set_serial_number(sn)
